Welcome to cryptoolz's documentation!
-------------------------------------

.. warning::

   Read AT LEAST **Usage** before using cryptoolz!

Contents
""""""""

.. toctree::
   :maxdepth: 1

   about
   motivation
   installation
   usage
   modules
   contributing
   authors
   history

Indices and tables
""""""""""""""""""
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
